# Generated by Django 4.1.2 on 2022-11-19 15:55

from django.db import migrations, models
import utilities.json


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0019_update_ns_ttl"),
    ]

    operations = [
        migrations.AlterField(
            model_name="nameserver",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name="record",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name="view",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
    ]
